# pypi_upgrade

![python_version](https://img.shields.io/static/v1?label=Python&message=3.5%20|%203.6%20|%203.7%20|%203.8000000000000003&color=blue) [![PyPI downloads/month](https://img.shields.io/pypi/dm/pypi_upgrade?logo=pypi&logoColor=white)](https://pypi.python.org/pypi/pypi_upgrade)

## Description

## Install

~~~~bash
pip install pypi_upgrade
# or
pip3 install pypi_upgrade
~~~~